Prerequisites
--------------

Compiling OGRE from source will need three things, that may not be installed by default:

1. **git** program to get the source from the server
2. **cmake** version 2.8 or newer (http://www.cmake.org). NB: **cmake** 3.1 is mandatory for macOS with boost 1.55 or newer.
3. **boost** version 1.46 or newer (http://www.boost.org)

Of course, default compilation tools (gcc, clang, make, etc.) are still needed to compile the program.

OGRE is known to compile on:
- Ubuntu 14.04 with g++ 4.8 and boost 1.46 for version 1.0.6
- Ubuntu 18.04 with g++ 8.3 and boost 1.67 for version 1.0.7

Semantic versioning
--------------

OGRE follows the pattern of semantic versioning: A.B.C with

- _A_ denoting a major update (breaking changes from previous version).
- _B_ denoting a minor update (adding new features but keeping intact the old ones).
- _C_ denoting a bug fix (fixing a bug or updating dependencies).

So versions 1.0.6 and versions 1.0.7 have exactly the same functionalities, but version 1.0.7 and version 1.1.0 should not.

Compilation
--------------

Following these few steps will lead you to an up and running version of OGRE

```bash
git clone --recursive HTTP_REPOSITORY_URL -b VERSION_YOU_WISH_TO_USE
mkdir build-ogre
cd build-ogre
cmake ../ogre
make
```

- *HTTP_REPOSITORY_URL*: Please use the http(s) repository URL and not the ssh one.
- *Version 1.0.6*: Please use this version if you are using an old version of boost and g++ (e.g. Ubuntu 14.04)
- *Version 1.0.7*: Please use this version if you are using a recent version of boost and g++ (e.g. Ubuntu 18.04)

Advanced options
--------------

In order to support DepXML file format, you need to have the xercesc library
installed (http://xerces.apache.org/xerces-c/).

To build OGRE with DepXML support, add the following option to the **cmake** step:

```bash
cmake ../ogre -DWITH_DEPXML=ON
```

Finally, if you want to compile OGRE test suites, you need to use:

```bash
cmake ../ogre -DWITH_TESTING=ON
```

**Warning**, OGRE testing needs **Boost Unit Test framework** to compile and run.

Known bugs
------------

- In MacOS 10.10 (Yosemite), OGRE can't compile with boost 1.5.7. Boost 1.5.5 works well enough.
